@@ -81,7 +81,7 @@ namespace Global {
 		{"#801414", "██████╔╝   ██║   ╚██████╔╝██║        ╚═╝    ╚═╝"},
 		{"#000000", "╚═════╝    ╚═╝    ╚═════╝ ╚═╝"},
 	};
-	const string Version = "1.4.1";
+	const string Version = "1.4.5";
 
 	int coreCount;
 	string overlay;
@@ -99,9 +99,7 @@ namespace Global {
 	string exit_error_msg;
 	atomic<bool> thread_exception (false);
 
-	bool debuginit{};
 	bool debug{};
-	bool utf_force{};
 
 	uint64_t start_time;
 
@@ -176,7 +174,7 @@ void term_resize(bool force) {
 				#else
 					if (intKey > 0 and intKey < 5) {
 				#endif
-						auto box = all_boxes.at(intKey);
+						const auto& box = all_boxes.at(intKey);
 						Config::current_preset = -1;
 						Config::toggle_box(box);
 						boxes = Config::getS("shown_boxes");
@@ -297,7 +295,7 @@ static void _signal_handler(const int sig) {
 }
 
 //* Config init
-void init_config(bool low_color) {
+void init_config(bool low_color, std::optional<std::string>& filter) {
 	atomic_lock lck(Global::init_conf);
 	vector<string> load_warnings;
 	Config::load(Config::conf_file, load_warnings);
@@ -311,6 +309,10 @@ void init_config(bool low_color) {
 	}
 	else Logger::set(Config::getS("log_level"));
 
+	if (filter.has_value()) {
+		Config::set("proc_filter", filter.value());
+	}
+
 	static string log_level;
 	if (const string current_level = Config::getS("log_level"); log_level != current_level) {
 		log_level = current_level;
@@ -783,6 +785,22 @@ namespace Runner {
 
 }
 
+static auto configure_tty_mode(std::optional<bool> force_tty) {
+	if (force_tty.has_value()) {
+		Config::set("tty_mode", force_tty.value());
+		Logger::debug("TTY mode set via command line");
+  	}
+
+#if !defined(__APPLE__) && !defined(__OpenBSD__) && !defined(__NetBSD__)
+	else if (Term::current_tty.starts_with("/dev/tty")) {
+		Config::set("tty_mode", true);
+		Logger::debug("Auto detect real TTY");
+  	}
+#endif
+
+	Logger::debug(fmt::format("TTY mode enabled: {}", Config::getB("tty_mode")));
+}
+
 
 //* --------------------------------------------- Main starts here! ---------------------------------------------------
 int main(const int argc, const char** argv) {
@@ -824,6 +842,8 @@ int main(const int argc, const char** argv) {
 		}
 	}
 
+	Global::debug = cli.debug;
+
 	{
 		const auto config_dir = Config::get_config_dir();
 		if (config_dir.has_value()) {
@@ -873,12 +893,12 @@ int main(const int argc, const char** argv) {
 	}
 
 	//? Config init
-	init_config(cli.low_color);
+	init_config(cli.low_color, cli.filter);
 
 	//? Try to find and set a UTF-8 locale
 	if (std::setlocale(LC_ALL, "") != nullptr and not s_contains((string)std::setlocale(LC_ALL, ""), ";")
 	and str_to_upper(s_replace((string)std::setlocale(LC_ALL, ""), "-", "")).ends_with("UTF8")) {
-		Logger::debug("Using locale " + (string)std::setlocale(LC_ALL, ""));
+		Logger::debug("Using locale " + std::locale().name());
 	}
 	else {
 		string found;
@@ -931,15 +951,16 @@ int main(const int argc, const char** argv) {
 			}
 		}
 	#else
-		if (found.empty() and Global::utf_force)
-			Logger::warning("No UTF-8 locale detected! Forcing start with --utf-force argument.");
-		else if (found.empty()) {
-			Global::exit_error_msg = "No UTF-8 locale detected!\nUse --utf-force argument to force start if you're sure your terminal can handle it.";
+		if (found.empty() and cli.force_utf) {
+			Logger::warning("No UTF-8 locale detected! Forcing start with --force-utf argument.");
+		} else if (found.empty()) {
+			Global::exit_error_msg = "No UTF-8 locale detected!\nUse --force-utf argument to force start if you're sure your terminal can handle it.";
 			clean_quit(1);
 		}
 	#endif
-		else if (not set_failure)
+		else if (not set_failure) {
 			Logger::debug("Setting LC_ALL=" + found);
+		}
 	}
 
 	//? Initialize terminal and set options
@@ -948,17 +969,11 @@ int main(const int argc, const char** argv) {
 		clean_quit(1);
 	}
 
-	if (Term::current_tty != "unknown") Logger::info("Running on " + Term::current_tty);
-	if ((!cli.force_tty.has_value() || !cli.force_tty.value()) && Config::getB("force_tty")) {
-		Config::set("tty_mode", true);
-		Logger::info("Forcing tty mode: setting 16 color mode and using tty friendly graph symbols");
+	if (Term::current_tty != "unknown") {
+		Logger::info("Running on " + Term::current_tty);
 	}
-#if not defined __APPLE__ && not defined __OpenBSD__ && not defined __NetBSD__
-	else if ((!cli.force_tty.has_value() || !cli.force_tty.value()) && Term::current_tty.starts_with("/dev/tty")) {
-		Config::set("tty_mode", true);
-		Logger::info("Real tty detected: setting 16 color mode and using tty friendly graph symbols");
-	}
-#endif
+
+	configure_tty_mode(cli.force_tty);
 
 	//? Check for valid terminal dimensions
 	{
@@ -1063,7 +1078,7 @@ int main(const int argc, const char** argv) {
 				Global::reload_conf = false;
 				if (Runner::active) Runner::stop();
 				Config::unlock();
-				init_config(cli.low_color);
+				init_config(cli.low_color, cli.filter);
 				Theme::updateThemes();
 				Theme::setTheme();
 				Draw::banner_gen(0, 0, false, true);
