@@ -26,6 +26,7 @@ tab-size = 4
 #include <optional>
 #include <ranges>
 #include <sstream>
+#include <string_view>
 #include <utility>
 
 #include <fcntl.h>
@@ -33,7 +34,6 @@ tab-size = 4
 #include <termios.h>
 #include <unistd.h>
 
-#include "unordered_map"
 #include "widechar_width.hpp"
 #include "btop_shared.hpp"
 #include "btop_tools.hpp"
@@ -211,11 +211,11 @@ namespace Term {
 
 namespace Tools {
 
-	size_t wide_ulen(const string& str) {
+	size_t wide_ulen(const std::string_view str) {
 		unsigned int chars = 0;
 		try {
 			std::wstring_convert<std::codecvt_utf8<wchar_t>> conv;
-			auto w_str = conv.from_bytes((str.size() > 10000 ? str.substr(0, 10000).c_str() : str.c_str()));
+			auto w_str = conv.from_bytes((str.size() > 10000 ? str.substr(0, 10000).data() : str.data()));
 
 			for (auto c : w_str) {
 				chars += utf8::wcwidth(c);
@@ -228,7 +228,7 @@ namespace Tools {
 		return chars;
 	}
 
-	size_t wide_ulen(const std::wstring& w_str) {
+	size_t wide_ulen(const std::wstring_view w_str) {
 		unsigned int chars = 0;
 
 		for (auto c : w_str) {
@@ -447,7 +447,7 @@ namespace Tools {
 			while (value >= 100000) {
 				value /= 1000;
 				if (value < 100) {
-					out = to_string(value);
+					out = fmt::format("{}", value);
 					break;
 				}
 				start++;
@@ -457,14 +457,14 @@ namespace Tools {
 			while (value >= 102400) {
 				value >>= 10;
 				if (value < 100) {
-					out = to_string(value);
+					out = fmt::format("{}", value);
 					break;
 				}
 				start++;
 			}
 		}
 		if (out.empty()) {
-			out = to_string(value);
+			out = fmt::format("{}", value);
 			if (not mega and out.size() == 4 and start > 0) {
 				out.pop_back();
 				out.insert(2, ".");
@@ -475,17 +475,21 @@ namespace Tools {
 			else if (out.size() >= 2) {
 				out.resize(out.size() - 2);
 			}
+			if (out.empty()) {
+				out = "0";
+			}
 		}
+
 		if (shorten) {
-			auto f_pos = out.find('.');
+			auto f_pos = out.find(".");
 			if (f_pos == 1 and out.size() > 3) {
-				out = to_string(round(stod(out) * 10) / 10).substr(0,3);
+				out = fmt::format("{:.1f}", stod(out));
 			}
 			else if (f_pos != string::npos) {
-				out = to_string((int)round(stod(out)));
+				out = fmt::format("{:.0f}", stod(out));
 			}
 			if (out.size() > 3) {
-				out = to_string((int)(out[0] - '0')) + ".0";
+				out = fmt::format("{:d}.0", out[0] - '0');
 				start++;
 			}
 			out.push_back(units[start][0]);
@@ -578,7 +582,8 @@ namespace Tools {
 		return (user != nullptr ? user : "");
 	}
 
-	DebugTimer::DebugTimer(const string name, bool start, bool delayed_report) : name(name), delayed_report(delayed_report) {
+	DebugTimer::DebugTimer(string name, bool start, bool delayed_report)
+			: name(std::move(name)), delayed_report(delayed_report) {
 		if (start)
 			this->start();
 	}
@@ -681,7 +686,7 @@ namespace Logger {
 		loglevel = v_index(log_levels, level);
 	}
 
-	void log_write(const Level level, const string& msg) {
+	void log_write(const Level level, const std::string_view msg) {
 		if (loglevel < level or !logfile.has_value()) {
 			return;
 		}
